package net.wanji.opt.service.impl;

import lombok.extern.slf4j.Slf4j;
import net.wanji.common.utils.tool.CrossUtil;
import net.wanji.databus.dao.mapper.CrossDataRealtimeMapper;
import net.wanji.databus.vo.RunningEvaluateCrossListVO;
import net.wanji.opt.bo.CrossNameBO;
import net.wanji.opt.service.RunningEvaluateService;
import org.springframework.stereotype.Service;

import java.util.Comparator;
import java.util.List;
import java.util.stream.Collectors;

/**
 * @author Kent HAN
 * @date 2023/8/21 9:53
 */
@Slf4j
@Service
public class RunningEvaluateServiceImpl implements RunningEvaluateService {
    private final CrossDataRealtimeMapper crossDataRealtimeMapper;
    public RunningEvaluateServiceImpl(CrossDataRealtimeMapper crossDataRealtimeMapper) {
        this.crossDataRealtimeMapper = crossDataRealtimeMapper;
    }

    @Override
    public List<RunningEvaluateCrossListVO> crossList(CrossNameBO crossNameBO) {
        String crossName = crossNameBO.getCrossName();
        List<RunningEvaluateCrossListVO> crossDataRealtimePOList = crossDataRealtimeMapper.selectByCrossName(crossName);
        for (RunningEvaluateCrossListVO runningEvaluateCrossListVO : crossDataRealtimePOList) {
            Double sturation = runningEvaluateCrossListVO.getSturation();
            runningEvaluateCrossListVO.setServiceLevel(CrossUtil.getServiceLevel(sturation));
        }
        // 按服务水平降序排序
        List<RunningEvaluateCrossListVO> res = crossDataRealtimePOList.stream()
                .sorted(Comparator.comparing(RunningEvaluateCrossListVO::getSturation).reversed())
                .collect(Collectors.toList());

        return res;
    }
}
